@@ -3,20 +3,20 @@ import sys
 
 import caching
 
-sys.path.append(os.path.abspath('..'))
+sys.path.append(os.path.abspath(".."))
 
 
 # The suffix of source filenames.
-source_suffix = '.rst'
+source_suffix = ".rst"
 
 # The master toctree document.
-master_doc = 'index'
+master_doc = "index"
 
-extensions = ['sphinx.ext.autodoc']
+extensions = ["sphinx.ext.autodoc"]
 
 # General information about the project.
-project = u'Cache Machine'
-copyright = u'2010, The Zamboni Collective'
+project = "Cache Machine"
+copyright = "2010, The Zamboni Collective"
 
 # The version info for the project you're documenting, acts as replacement for
 # |version| and |release|, also used in various other places throughout the
@@ -28,4 +28,4 @@ version = release = caching.__version__
 
 # List of directories, relative to source directory, that shouldn't be searched
 # for source files.
-exclude_trees = ['_build']
+exclude_trees = ["_build"]
