@@ -2,4 +2,4 @@
 from .settings import *
 
 CACHE_MACHINE_USE_REDIS = True
-REDIS_BACKEND = 'redis://'
+REDIS_BACKEND = "redis://"
